@@ -8,13 +8,13 @@ from datetime import timedelta
 # third party imports
 import numpy as np
 import pandas as pd
-from esi_utils_io.container import HDFContainer
 from mapio.reader import get_file_geodict, read
 from mapio.shake import ShakeGrid
 
 # local imports
 from esi_utils_pager.country import Country
 from esi_utils_pager.growth import PopulationGrowth
+from esi_utils_pager.pandas_container import PandasContainer
 
 # constants indicating what values in urban/rural grid stand for
 URBAN = 2
@@ -77,7 +77,8 @@ def pop_dist(popi, workforce, time, dclass):
     :param popi:
       Total population.
     :param workforce:
-      Pandas Series containing indices (WorkForceTotal,WorkForceAgricultural,WorkForceIndustrial,WorkForceServices)
+      Pandas Series containing indices (WorkForceTotal,WorkForceAgricultural,
+        WorkForceIndustrial,WorkForceServices)
     :param time: Time of day ('day','night','transit')
     :param dclass: Density class (URBAN,RURAL)
     :return: Tuple of (residential,non-residential,outdoor) population numbers.
@@ -305,7 +306,7 @@ class SemiEmpiricalFatality(object):
         """Create Semi-Empirical Fatality Model object.
 
         :param inventory:
-          HDFContainer, containing DataFrames named:
+          PandasContainer, containing DataFrames named:
            - 'BuildingTypes',
            - 'RuralNonResidential'
            - 'RuralResidential'
@@ -314,31 +315,40 @@ class SemiEmpiricalFatality(object):
 
            where BuildingTypes is a Dataframe with columns:
              - Code: Building Code ('A','S','C1',etc.)
-             - ShortDescription:  A short description of building type (i.e, 'adobe block').
-             - OperationalDescription: A (sometimes) shorter description of building type.
-             - LongDescription: Full description of building type, i.e. 'High-Rise Ductile Reinforced Concrete Moment Frame'
+             - ShortDescription:  A short description of building type
+                                  (i.e, 'adobe block').
+             - OperationalDescription: A (sometimes) shorter description of
+                                       building type.
+             - LongDescription: Full description of building type,
+                                i.e. 'High-Rise Ductile Reinforced Concrete Moment
+                                Frame'
           All other Dataframes have columns:
             - CountryCode: Two letter ISO country code ('US',etc.)
             - CountryName: Name of country.
             - Building Codes, as listed and described in BuildingTypes Dataframe.
 
         :param collapse:
-          HDFContainer, where first index is country (by two-letter country code), columns are:
+          PandasContainer, where first index is country (by two-letter country code),
+            columns are:
             - BuildingCode:  Building code as above.
-            - (IMT)_6.0 -> (IMT)_9.0 Columns with collapse rates at each (IMT) interval, where (IMT) could be MMI,PGA,PGV,PSA1.0, etc.
+            - (IMT)_6.0 -> (IMT)_9.0 Columns with collapse rates at each (IMT) interval,
+                           where (IMT) could be MMI,PGA,PGV,PSA1.0, etc.
 
         :param casualty:
-          HDFContainer, where first index is country (by two-letter country code), columns are:
+          PandasContainer, where first index is country (by two-letter country code),
+            columns are:
             - BuildingCode:  Building code as above.
             - CasualtyDay:   Casualty rate, given collapse, during the day.
             - CasualtyNight: Casualty rate, given collapse, during the night.
 
         :param workforce:
-          HDFContainer consisting of a single dataframe, where rows are by country, and columns are:
+          PandasContainer consisting of a single dataframe, where rows are by country,
+              and columns are:
             - CountryCode two letter ISO country code.
             - CountryCode name of country.
             - WorkforceTotal Fraction of the country population in the workforce.
-            - WorkforceAgriculture Fraction of the total workforce employed in agriculture.
+            - WorkforceAgriculture Fraction of the total workforce employed in
+              agriculture.
             - WorkforceIndustrial Fraction of the total workforce employed in industry.
             - WorkforceServices Fraction of the total workforce employed in services.
         :param growth:
@@ -355,10 +365,10 @@ class SemiEmpiricalFatality(object):
     @classmethod
     def fromDefault(cls):
         homedir = pathlib.Path(__file__).parent  # where is this module?
-        inventory_file = homedir / "data" / "semi_inventory.hdf"
-        collapse_file = homedir / "data" / "semi_collapse_mmi.hdf"
-        casualty_file = homedir / "data" / "semi_casualty.hdf"
-        workforce_file = homedir / "data" / "semi_workforce.hdf"
+        inventory_file = homedir / "data" / "semi_inventory.xlsx"
+        collapse_file = homedir / "data" / "semi_collapse_mmi.xlsx"
+        casualty_file = homedir / "data" / "semi_casualty.xlsx"
+        workforce_file = homedir / "data" / "semi_workforce.xlsx"
         return cls.fromFiles(
             inventory_file, collapse_file, casualty_file, workforce_file
         )
@@ -368,23 +378,28 @@ class SemiEmpiricalFatality(object):
         """Create SemiEmpiricalFatality object from a number of input files.
 
         :param inventory_file:
-          HDF5 file containing Semi-Empirical building inventory data in an HDFContainer. (described in __init__).
+          Excel file containing Semi-Empirical building inventory data.
+          (described in __init__).
         :param collapse_file:
-          HDF5 file containing Semi-Empirical collapse rate data  in an HDFContainer. (described in __init__).
+          Excel file containing Semi-Empirical collapse rate data  in an PandasContainer.
+          (described in __init__).
         :param casualty_file:
-          HDF5 file containing Semi-Empirical casualty rate data in an HDFContainer.(described in __init__).
+          Excel file containing Semi-Empirical casualty rate data in an PandasContainer.
+          (described in __init__).
         :param workforce_file:
-          HDF5 file containing Semi-Empirical workforce data in an HDFContainer. (described in __init__).
+          Excel file containing Semi-Empirical workforce data in an PandasContainer.
+          (described in __init__).
         :param growth_file:
-          Excel spreadsheet containing population growth rate data (described in PopulationGrowth.fromUNSpreadsheet()).
+          Excel spreadsheet containing population growth rate data
+          (described in PopulationGrowth.fromUNSpreadsheet()).
         :returns:
           SemiEmpiricalFatality object.
         """
         # turn the inventory,collapse, and casualty spreadsheets into Panels...
-        inventory = HDFContainer.load(inventory_file)
-        collapse = HDFContainer.load(collapse_file)
-        casualty = HDFContainer.load(casualty_file)
-        workforce = HDFContainer.load(workforce_file)
+        inventory = PandasContainer(inventory_file)
+        collapse = PandasContainer(collapse_file)
+        casualty = PandasContainer(casualty_file)
+        workforce = PandasContainer(workforce_file)
         # extract the one dataframe from the Panel
         workforce = workforce.getDataFrame("Workforce")
         workforce = workforce.set_index("CountryCode")
@@ -395,14 +410,14 @@ class SemiEmpiricalFatality(object):
         return cls(inventory, collapse, casualty, workforce, popgrowth)
 
     def setGlobalFiles(self, popfile, popyear, urbanfile, isofile):
-        """Set the global data files (population,urban/rural, country code) for use of model with ShakeMaps.
+        """Set global files (pop,urban/rural, country code) for use of model with ShakeMaps.
 
         :param popfile:
           File name of population grid.
         :param popyear:
           Year population data was collected.
         :param urbanfile:
-          File name of urban/rural grid (rural cells indicated with a 1, urban cells with a 2).
+          File name of urban/rural grid (rural cells contain 1, urban cells contain 2).
         :param isofile:
           File name of numeric ISO country code grid.
         :returns:
@@ -421,8 +436,10 @@ class SemiEmpiricalFatality(object):
         :param desctype:
           A string, one of:
             - 'short': Very short descriptions ('adobe block')
-            - 'operational': Short description, intended for use in automatically generated sentences about building types.
-            - 'long': Most verbose description ('Adobe block (unbaked dried mud block) walls')
+            - 'operational': Short description, intended for use in automatically
+               generated sentences about building types.
+            - 'long': Most verbose description
+               ('Adobe block (unbaked dried mud block) walls')
 
         :returns:
           Either a short, operational, or long description of building types.
@@ -448,7 +465,7 @@ class SemiEmpiricalFatality(object):
         """
         try:
             wforce = self._workforce.loc[ccode]
-        except:
+        except Exception:
             wforce = None
         return wforce
 
@@ -462,13 +479,13 @@ class SemiEmpiricalFatality(object):
         :param inventory:
           Pandas Series containing an inventory for the given country.
         :returns:
-          Pandas Series object containing the collapse rates for given building types, ccode, and MMI.
+          Pandas Series object containing the collapse rates for given building types,
+          ccode, and MMI.
         """
         collapse_frame = self._collapse.getDataFrame(ccode)
         collapse_frame = collapse_frame.set_index("BuildingCode")
         collapse_frame = collapse_frame.loc[inventory.index]
-        if "Unnamed: 0" in collapse_frame.columns:
-            collapse_frame.drop("Unnamed: 0", axis="columns")
+
         mmicol = f"MMI_{mmi:.1f}"
         collapse = collapse_frame[mmicol]
         return collapse
@@ -483,20 +500,18 @@ class SemiEmpiricalFatality(object):
         :param inventory:
           Pandas Series containing an inventory for the given country.
         :returns:
-          Pandas Series object containing fatality rates for given country, time of day, and inventory.
+          Pandas Series object containing fatality rates for given country, time of day,
+          and inventory.
         """
         fatalframe = self._casualty.getDataFrame(ccode)
         fatalframe = fatalframe.set_index("BuildingCode")
         timecol = TIMES[timeofday]
-        if "Unnamed: 0" in inventory.index:
-            idx = inventory.index.drop("Unnamed: 0")
-        else:
-            idx = inventory.index
+        idx = inventory.index
         fatrates = fatalframe.loc[idx][timecol]
         return fatrates
 
     def getInventories(self, ccode, density):
-        """Return two pandas Series objects corresponding to the urban or rural inventory for given country.
+        """Return two pandas Series objects with urban or rural inventory for given country.
 
         :param ccode:
           Two-letter ISO country code.
@@ -514,7 +529,8 @@ class SemiEmpiricalFatality(object):
         resinv = resinv.set_index("CountryCode")
         nresinv = nresinv.set_index("CountryCode")
 
-        # we may be missing inventory for certain countries (Bonaire?). Return empty series.
+        # we may be missing inventory for certain countries (Bonaire?). Return empty
+        # series.
         if ccode not in resinv.index or ccode not in nresinv.index:
             return (pd.Series(), pd.Series())
 
@@ -531,13 +547,6 @@ class SemiEmpiricalFatality(object):
         nresrow = nresrow[nresrow.notnull()]
         nresrow = nresrow[nresrow > 0]
 
-        # some of these dataframes may have been created with a column
-        # meant to be the index. If present, remove these indices from the
-        # series being returned here
-        if "Unnamed: 0" in resrow.index:
-            resrow.drop("Unnamed: 0", inplace=True)
-        if "Unnamed: 0" in nresrow.index:
-            nresrow.drop("Unnamed: 0", inplace=True)
         return (resrow, nresrow)
 
     def getLosses(self, shakefile):
@@ -619,7 +628,8 @@ class SemiEmpiricalFatality(object):
                 popdata[cidx], ccode, self._popyear, event_year
             )
 
-        # create a dictionary containing indoor populations by building type (in cells where MMI >= 6)
+        # create a dictionary containing indoor populations by building type (in cells
+        # where MMI >= 6)
         # popbystruct = get_indoor_pop(mmidata,popdata,urbdata,isodata,time_of_day)
 
         # find all mmi values greater than 9, set them to 9
@@ -657,11 +667,15 @@ class SemiEmpiricalFatality(object):
                 for dclass in [URBAN, RURAL]:
                     c3 = urbdata == dclass
 
-                    # get the population data in those cells at MMI, in country, and density class
+                    # get the population data in those cells at MMI, in country, and
+                    # density class
                     # I think I want an AND condition here
                     popcells = popdata[c1 & c2 & c3]
+                    if not len(popcells):
+                        continue
 
-                    # get the population distribution across residential, non-residential, and outdoor.
+                    # get the population distribution across residential,
+                    # non-residential, and outdoor.
                     res, nonres, outside = pop_dist(
                         popcells, wforce, time_of_day, dclass
                     )
@@ -669,7 +683,8 @@ class SemiEmpiricalFatality(object):
                     # get the inventory for urban residential
                     resrow, nresrow = self.getInventories(ccode, dclass)
 
-                    # now multiply the residential/non-residential population through the inventory data
+                    # now multiply the residential/non-residential population through
+                    # the inventory data
                     numres = len(resrow)
                     numnonres = len(nresrow)
                     resmat = np.reshape(resrow.values, (numres, 1)).astype(np.float32)
@@ -684,7 +699,8 @@ class SemiEmpiricalFatality(object):
                     # now we have the residential and non-residental population
                     # distributed through the building types for each cell that matches
                     # MMI,country, and density criteria.
-                    # popresbuilding rows are building types, columns are population cells
+                    # popresbuilding rows are building types, columns are population
+                    # cells
 
                     # next, we get the collapse rates for these buildings
                     # and multiply them by the population by building.
@@ -716,12 +732,12 @@ class SemiEmpiricalFatality(object):
                     try:
                         if len(resfat) and len(resfat[0]):
                             resfat[np.ma.masked_less(resfat, 1).mask] = 0.0
-                    except:
+                    except Exception:
                         resfat[np.isnan(resfat)] = 0.0
                     try:
                         if len(nonresfat) and len(nonresfat[0]):
                             nonresfat[np.ma.masked_less(nonresfat, 1).mask] = 0.0
-                    except:
+                    except Exception:
                         nonresfat[np.isnan(nonresfat)] = 0.0
 
                     # sum the fatalities per building through all cells
@@ -734,7 +750,8 @@ class SemiEmpiricalFatality(object):
                         nonres_fatal_by_btype, nonresfdict
                     )
 
-            # add the fatalities by building type to the dictionary containing fatalities by country
+            # add the fatalities by building type to the dictionary containing
+            # fatalities by country
             res_fatal_by_ccode[ccode] = res_fatal_by_btype.copy()
             nonres_fatal_by_ccode[ccode] = nonres_fatal_by_btype.copy()
 
